@@ -8,10 +8,8 @@ from unittest.mock import MagicMock, patch
 
 from gvm.errors import GvmError
 from gvm.protocols.gmp import Gmp
-from gvm.protocols.gmpv208 import Gmp as Gmpv208
-from gvm.protocols.gmpv214 import Gmp as Gmpv214
-from gvm.protocols.gmpv224 import Gmp as Gmpv224
-from gvm.protocols.gmpv225 import Gmp as Gmpv225
+from gvm.protocols.gmp._gmp224 import GMPv224
+from gvm.protocols.gmp._gmp225 import GMPv225
 from tests.protocols import GmpTestCase
 
 
@@ -20,9 +18,9 @@ class GmpContextManagerTestCase(GmpTestCase):
 
     def test_select_gmpv7(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>7.0</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>7.0</version>"
+            b"</get_version_response>"
         )
 
         with self.assertRaises(GvmError):
@@ -31,9 +29,9 @@ class GmpContextManagerTestCase(GmpTestCase):
 
     def test_select_gmpv8(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>8.0</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>8.0</version>"
+            b"</get_version_response>"
         )
 
         with self.assertRaises(GvmError):
@@ -42,9 +40,9 @@ class GmpContextManagerTestCase(GmpTestCase):
 
     def test_select_gmpv9(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>9.0</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>9.0</version>"
+            b"</get_version_response>"
         )
 
         with self.assertRaises(GvmError):
@@ -53,53 +51,52 @@ class GmpContextManagerTestCase(GmpTestCase):
 
     def test_select_gmpv208(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>20.08</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>20.08</version>"
+            b"</get_version_response>"
         )
-
-        with self.gmp as gmp:
-            self.assertEqual(gmp.get_protocol_version(), (20, 8))
-            self.assertIsInstance(gmp, Gmpv208)
+        with self.assertRaises(GvmError):
+            with self.gmp:
+                pass
 
     def test_select_gmpv214(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>21.04</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>21.04</version>"
+            b"</get_version_response>"
         )
 
-        with self.gmp as gmp:
-            self.assertEqual(gmp.get_protocol_version(), (21, 4))
-            self.assertIsInstance(gmp, Gmpv214)
+        with self.assertRaises(GvmError):
+            with self.gmp:
+                pass
 
     def test_select_gmpv224(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>22.04</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>22.04</version>"
+            b"</get_version_response>"
         )
 
         with self.gmp as gmp:
             self.assertEqual(gmp.get_protocol_version(), (22, 4))
-            self.assertIsInstance(gmp, Gmpv224)
+            self.assertIsInstance(gmp, GMPv224)
 
     def test_select_gmpv225(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>22.05</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>22.05</version>"
+            b"</get_version_response>"
         )
 
         with self.gmp as gmp:
             self.assertEqual(gmp.get_protocol_version(), (22, 5))
-            self.assertIsInstance(gmp, Gmpv225)
+            self.assertIsInstance(gmp, GMPv225)
 
     def test_unknown_protocol(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>1.0</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>1.0</version>"
+            b"</get_version_response>"
         )
 
         with self.assertRaises(GvmError):
@@ -108,9 +105,9 @@ class GmpContextManagerTestCase(GmpTestCase):
 
     def test_missing_version_in_response(self):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<foo>bar</foo>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<foo>bar</foo>"
+            b"</get_version_response>"
         )
 
         with self.assertRaises(GvmError):
@@ -118,18 +115,18 @@ class GmpContextManagerTestCase(GmpTestCase):
                 pass
 
     def test_invalid_response(self):
-        self.connection.read.return_value("<get_foo_response/>")
+        self.connection.read.return_value(b"<get_foo_response/>")
 
         with self.assertRaises(GvmError):
             with self.gmp:
                 pass
 
-    @patch("gvm.protocols.gmp.Gmpv214")
+    @patch("gvm.protocols.gmp._gmp.GMPv224", autospec=True)
     def test_connect_disconnect(self, gmp_mock: MagicMock):
         self.connection.read.return_value(
-            '<get_version_response status="200" status_text="OK">'
-            "<version>21.04</version>"
-            "</get_version_response>"
+            b'<get_version_response status="200" status_text="OK">'
+            b"<version>22.04</version>"
+            b"</get_version_response>"
         )
 
         with self.gmp:
