@@ -4,7 +4,7 @@
 #
 
 from ...gmpv224 import Gmpv224TestCase
-from ...gmpv224.entities.scan_configs import (
+from .scan_configs import (
     GmpCloneScanConfigTestMixin,
     GmpCreateScanConfigTestMixin,
     GmpDeleteScanConfigTestMixin,
@@ -17,7 +17,6 @@ from ...gmpv224.entities.scan_configs import (
     GmpModifyScanConfigSetNvtPreferenceTestMixin,
     GmpModifyScanConfigSetNvtSelectionTestMixin,
     GmpModifyScanConfigSetScannerPreferenceTestMixin,
-    GmpModifyScanConfigTestMixin,
 )
 
 
@@ -89,9 +88,3 @@ class Gmpv224ModifyScanConfigSetScannerPreferenceTestCase(
     GmpModifyScanConfigSetScannerPreferenceTestMixin, Gmpv224TestCase
 ):
     pass
-
-
-class Gmpv224ModifyScanConfigTestCase(
-    GmpModifyScanConfigTestMixin, Gmpv224TestCase
-):
-    pass
