@@ -3,8 +3,8 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
 
-from ...gmpv208.system.system_reports import GmpGetSystemReportsTestMixin
 from ...gmpv224 import Gmpv224TestCase
+from .system_reports import GmpGetSystemReportsTestMixin
 
 
 class Gmpv224GetSystemReportsTestCase(
